@@ -511,7 +511,12 @@ as_utils_find_files_matching (const gchar* dir, const gchar* pattern, gboolean r
 
 	list = g_ptr_array_new_with_free_func (g_free);
 	fdir =  g_file_new_for_path (dir);
-	enumerator = g_file_enumerate_children (fdir, G_FILE_ATTRIBUTE_STANDARD_NAME, 0, NULL, &tmp_error);
+	enumerator = g_file_enumerate_children (fdir,
+						G_FILE_ATTRIBUTE_STANDARD_NAME ","
+						G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN,
+						0,
+						NULL,
+						&tmp_error);
 	if (tmp_error != NULL)
 		goto out;
 
@@ -570,6 +575,7 @@ out:
 			g_debug ("Error while searching for files in %s: %s", dir, tmp_error->message);
 		else
 			g_propagate_error (error, tmp_error);
+		g_error_free (tmp_error);
 		g_ptr_array_unref (list);
 		return NULL;
 	}
@@ -628,15 +634,14 @@ as_utils_is_writable (const gchar *path)
 }
 
 /**
- * as_get_current_locale:
+ * as_get_current_locale_posix:
  *
- * Returns the current locale string in the format
- * used by the AppStream.
+ * Returns the current locale string in the POSIX format.
  *
  * Returns: (transfer full): A locale string, free with g_free()
  */
 gchar*
-as_get_current_locale (void)
+as_get_current_locale_posix (void)
 {
 	const gchar * const *locale_names;
 	const gchar *locale = NULL;
@@ -659,6 +664,129 @@ as_get_current_locale (void)
 	return as_locale_strip_encoding (locale);
 }
 
+/**
+ * as_get_current_locale_bcp47:
+ *
+ * Returns the current locale string in the IETF BCP 47 format
+ * for use in AppStream XML.
+ *
+ * Returns: (transfer full): A locale string, free with g_free()
+ */
+gchar*
+as_get_current_locale_bcp47 (void)
+{
+	g_autofree gchar *locale = as_get_current_locale_posix ();
+	return as_utils_posix_locale_to_bcp47 (locale);
+}
+
+/**
+ * as_utils_posix_locale_to_bcp47:
+ *
+ * Converts a POSIX locale string to the corresponding IETF BCP47 format.
+ * If the given locale is already in BCP47 format, no change will be done.
+ *
+ * Returns: (transfer full): A locale string, free with g_free()
+ */
+gchar*
+as_utils_posix_locale_to_bcp47 (const gchar *locale)
+{
+	g_autoptr(GString) bcp47 = NULL;
+	gboolean has_variant = FALSE;
+	guint i;
+	if (locale == NULL)
+		return NULL;
+
+	bcp47 = g_string_sized_new (strlen (locale));
+	for (i = 0; locale[i] != '\0'; i++) {
+		if (locale[i] == '_') {
+			g_string_append_c (bcp47, '-');
+		} else if (locale[i] == '@') {
+			has_variant = TRUE;
+			break;
+		} else {
+			g_string_append_c (bcp47, locale[i]);
+		}
+	}
+
+	if (has_variant) {
+		if (g_str_has_prefix (locale + i, "@cyrillic"))
+			g_string_append (bcp47, "-Cyrl");
+		else if (g_str_has_prefix (locale + i, "@devanagari"))
+			g_string_append (bcp47, "-Deva");
+		else if (g_str_has_prefix (locale + i, "@latin"))
+			g_string_append (bcp47, "-Latn");
+		else if (g_str_has_prefix (locale + i, "@shaw"))
+			g_string_append (bcp47, "-Shaw");
+		else if (!g_str_has_prefix (locale + i, "@euro")) {
+			g_string_append_c (bcp47, '-');
+			g_string_append (bcp47, locale + i + 1);
+		}
+	}
+
+	return g_string_free (g_steal_pointer (&bcp47), FALSE);
+}
+
+/**
+ * as_locale_is_posix:
+ * @locale: (nullable): The locale to test.
+ *
+ * Guess if the given locale is in POSIX format, or whether it is
+ * in another format, e.g. BCP47.
+ *
+ * Returns: %TRUE if we have a POSIX locale, %FALSE otherwise.
+ */
+gboolean
+as_locale_is_posix (const gchar *locale)
+{
+	/* we assume NULL is valid, for compatibility */
+	if (locale == NULL)
+		return TRUE;
+
+	for (guint i = 0; locale[i] != '\0'; i++) {
+		if (locale[i] == '-')
+			return FALSE;
+		if (locale[i] == '_')
+			return TRUE;
+		if (locale[i] == '@')
+			return TRUE;
+	}
+
+	/* if we are here, the string contained no hyphens (which would indicate BCP47),
+	 * but also no underscores or @ (which would indicate POSIX), so it may be something
+	 * like "de", for which we simply assume it is a POSIX locale. */
+	return TRUE;
+}
+
+/**
+ * as_locale_is_bcp47:
+ * @locale: (nullable): The locale to test.
+ *
+ * Guess if the given locale is in BCP47 format.
+ *
+ * Returns: %TRUE if we likely have a BCP47 locale, %FALSE otherwise.
+ */
+gboolean
+as_locale_is_bcp47 (const gchar *locale)
+{
+	/* we assume NULL is valid, for compatibility */
+	if (locale == NULL)
+		return TRUE;
+
+	for (guint i = 0; locale[i] != '\0'; i++) {
+		if (locale[i] == '-')
+			return TRUE;
+		if (locale[i] == '_')
+			return FALSE;
+		if (locale[i] == '@')
+			return FALSE;
+	}
+
+	/* if we are here, the string contained no hyphens (which would indicate BCP47),
+	 * but also no underscores or @ (which would indicate POSIX), so it may be something
+	 * like "de", for which we simply assume it is a BCP47 locale. */
+	return TRUE;
+}
+
 /**
  * as_ptr_array_to_strv:
  * @array: (element-type utf8)
@@ -932,9 +1060,9 @@ as_arch_compatible (const gchar *arch1, const gchar *arch2)
 
 /**
  * as_utils_locale_to_language:
- * @locale: The locale string.
+ * @locale: (nullable): the BCP47 or POSIX locale string.
  *
- * Get language part from a locale string.
+ * Get language part from a locale string in either BCP47 or POSIX format.
  */
 gchar*
 as_utils_locale_to_language (const gchar *locale)
@@ -946,11 +1074,17 @@ as_utils_locale_to_language (const gchar *locale)
 	if (locale == NULL)
 		return NULL;
 
-	/* return the part before the _ (not always 2 chars!) */
+	/* return the part before the - for BCP47 locale */
 	country_code = g_strdup (locale);
-	tmp = g_strstr_len (country_code, -1, "_");
-	if (tmp != NULL)
+	tmp = g_strstr_len (country_code, -1, "-");
+	if (tmp != NULL) {
 		*tmp = '\0';
+	} else {
+		/* return the part before the _ for POSIX locale (not always 2 chars!) */
+		tmp = g_strstr_len (country_code, -1, "_");
+		if (tmp != NULL)
+			*tmp = '\0';
+	}
 
 	/* return the part before any "@" for locale with modifiers like "ca@valencia" */
 	tmp = g_strstr_len (country_code, -1, "@");
@@ -1004,8 +1138,8 @@ as_hash_table_string_keys_to_array (GHashTable *table, GPtrArray *array)
 
 /**
  * as_utils_locale_is_compatible:
- * @locale1: a locale string, or %NULL
- * @locale2: a locale string, or %NULL
+ * @locale1: (nullable): a BCP47 or POSIX locale string, or %NULL
+ * @locale2: (nullable): a BCP47 or POSIX locale string, or %NULL
  *
  * Calculates if one locale is compatible with another.
  * When doing the calculation the locale and language code is taken into
@@ -2030,7 +2164,7 @@ as_utils_install_metadata_file_internal (const gchar *filename,
 			g_set_error (error,
 				     AS_UTILS_ERROR,
 				     AS_UTILS_ERROR_FAILED,
-				     "Name of metadata collection file is invalid %s",
+				     "Name of metadata catalog file is invalid %s",
 				     basename);
 			return FALSE;
 		}
@@ -2055,7 +2189,7 @@ as_utils_install_metadata_file_internal (const gchar *filename,
 		if (!as_metadata_parse_file (mdata, file_dest, AS_FORMAT_KIND_XML, error))
 			return FALSE;
 		as_metadata_set_origin (mdata, origin);
-		if (!as_metadata_save_collection (mdata, path_dest, AS_FORMAT_KIND_XML, error))
+		if (!as_metadata_save_catalog (mdata, path_dest, AS_FORMAT_KIND_XML, error))
 			return FALSE;
 	}
 
@@ -2101,7 +2235,7 @@ as_utils_install_icon_tarball (AsMetadataLocation location,
  * @destdir: the destdir to use, or %NULL
  * @error: A #GError or %NULL
  *
- * Installs an AppStream MetaInfo, AppStream Metadata Collection or AppStream Icon tarball file
+ * Installs an AppStream MetaInfo, AppStream Metadata Catalog or AppStream Icon tarball file
  * to the right place on the filesystem.
  * Please note that this function does almost no validation and may guess missing values such
  * as icon sizes and origin names.
@@ -2137,7 +2271,7 @@ as_utils_install_metadata_file (AsMetadataLocation location,
 		destdir = "";
 
 	switch (as_metadata_file_guess_style (filename)) {
-	case AS_FORMAT_STYLE_COLLECTION:
+	case AS_FORMAT_STYLE_CATALOG:
 		if (g_strstr_len (filename, -1, ".yml.gz") != NULL) {
 			path = g_build_filename (as_metadata_location_get_prefix (location),
 						 "swcatalog", "yaml", NULL);
